@@ -3,7 +3,7 @@ import Ajv from 'ajv';
 import { dirname, join } from 'path';
 import { fileURLToPath } from 'url';
 import { promises as fs } from 'fs';
-import { AjvOptions, DefaultTimeoutMillis } from '../../validation.js';
+import { AjvOptions, DefaultTimeoutMillis } from '../../../validation.js';
 
 const __dirname = dirname(fileURLToPath(import.meta.url));
 const schemaPath = join(__dirname, '..', 'schema.json');
