@@ -2,17 +2,16 @@ import sys
 from enum import IntEnum
 from http import HTTPStatus
 from json import dumps, load
-from typing import Callable, Union
+from typing import Callable, Optional, Union
 
 import boto3
-from botocore.exceptions import NoCredentialsError
+from botocore.exceptions import NoCredentialsError, NoRegionError
 from typer import Option, Typer, secho
 from typer.colors import GREEN, RED, YELLOW
 
-from geostore.dataset_keys import DATASET_KEY_SEPARATOR
-
 from .api_keys import MESSAGE_KEY
 from .aws_keys import BODY_KEY, HTTP_METHOD_KEY
+from .dataset_keys import DATASET_KEY_SEPARATOR
 from .resources import ResourceName
 from .step_function_keys import DATASET_ID_SHORT_KEY, DESCRIPTION_KEY, TITLE_KEY
 from .types import JsonList, JsonObject
@@ -21,6 +20,8 @@ app = Typer()
 dataset_app = Typer()
 app.add_typer(dataset_app, name="dataset")
 
+GetOutputFunctionType = Union[Callable[[JsonList], str], Callable[[JsonObject], str]]
+
 
 class ExitCode(IntEnum):
     SUCCESS = 0
@@ -28,10 +29,11 @@ class ExitCode(IntEnum):
     # Exit code 2 is used by Typer to indicate usage error
     CONFLICT = 3
     NO_CREDENTIALS = 4
+    NO_REGION_SETTING = 5
 
 
-@dataset_app.command()
-def create(title: str = Option(...), description: str = Option(...)) -> None:
+@dataset_app.command(name="create")
+def dataset_create(title: str = Option(...), description: str = Option(...)) -> None:
     request_object = {
         HTTP_METHOD_KEY: "POST",
         BODY_KEY: {TITLE_KEY: title, DESCRIPTION_KEY: description},
@@ -46,24 +48,41 @@ def create(title: str = Option(...), description: str = Option(...)) -> None:
 
 
 @dataset_app.command(name="list")
-def list_() -> None:
-    request_object = {HTTP_METHOD_KEY: "GET", BODY_KEY: {}}
+def dataset_list(id_: Optional[str] = Option(None, "--id")) -> None:
+    body = {}
+    get_output: GetOutputFunctionType
 
-    def get_output(response_body: JsonList) -> str:
-        lines = []
-        for entry in response_body:
-            lines.append(f"{entry['title']}{DATASET_KEY_SEPARATOR}{entry['id']}")
-        output = "\n".join(lines)
-        return output
+    if id_ is None:
 
-    handle_api_request(request_object, get_output)
+        def get_list_output(response_body: JsonList) -> str:
+            lines = []
+            for entry in response_body:
+                lines.append(f"{entry['title']}{DATASET_KEY_SEPARATOR}{entry['id']}")
+            return "\n".join(lines)
+
+        get_output = get_list_output
+
+    else:
+
+        def get_single_output(response_body: JsonObject) -> str:
+            return f"{response_body['title']}{DATASET_KEY_SEPARATOR}{response_body['id']}"
+
+        body[DATASET_ID_SHORT_KEY] = id_
+        get_output = get_single_output
+
+    handle_api_request({HTTP_METHOD_KEY: "GET", BODY_KEY: body}, get_output)
 
 
-def handle_api_request(
-    request_object: JsonObject,
-    get_output: Union[Callable[[JsonList], str], Callable[[JsonObject], str]],
-) -> None:
-    client = boto3.client("lambda")
+def handle_api_request(request_object: JsonObject, get_output: GetOutputFunctionType) -> None:
+    try:
+        client = boto3.client("lambda")
+    except NoRegionError:
+        secho(
+            "Unable to locate region settings. Make sure to log in to AWS first.",
+            err=True,
+            fg=YELLOW,
+        )
+        sys.exit(ExitCode.NO_REGION_SETTING)
 
     request_payload = dumps(request_object).encode()
 
